<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-aide?lang_cible=es
// ** ne pas modifier le fichier **

return [

	// A
	'aide_description' => 'Este plugin permite que SPIP incluya ayuda contextual marcada con un icono. Esta ayuda también se puede extender a los plugins.',
	'aide_nom' => 'Ayuda SPIP',
	'aide_slogan' => 'Ayuda en línea de SPIP',
];
